package boshclient_test

import (
	"crypto/x509"
	"encoding/pem"
	"log"

	"github.com/pivotal-cf/on-demand-service-broker/authorizationheader/fake_auth_header_builder"
	"github.com/pivotal-cf/on-demand-service-broker/boshclient"
	"github.com/pivotal-cf/on-demand-service-broker/mockbosh"
	"github.com/pivotal-cf/on-demand-service-broker/mockhttp"

	. "github.com/onsi/ginkgo"
	. "github.com/onsi/gomega"

	"testing"
)

const (
	boshUsername       = "boshUsername"
	boshPassword       = "boshPassword"
	expectedAuthHeader = "some-auth-header"
)

var (
	c *boshclient.Client

	authHeaderBuilder *fake_auth_header_builder.FakeAuthHeaderBuilder
	director          *mockhttp.Server
	shouldFail        bool
	logger            *log.Logger
)

var _ = BeforeEach(func() {
	authHeaderBuilder = new(fake_auth_header_builder.FakeAuthHeaderBuilder)
	authHeaderBuilder.BuildReturns(expectedAuthHeader, nil)
	director = mockbosh.New()
	director.ExpectedAuthorizationHeader(expectedAuthHeader)
	logger = log.New(GinkgoWriter, "[boshclient unit test]", log.LstdFlags)
})

var _ = AfterEach(func() {
	director.VerifyMocks()
	director.Close()
})

var _ = JustBeforeEach(func() {
	var certPEM []byte
	if director.TLS != nil {
		cert, err := x509.ParseCertificate(director.TLS.Certificates[0].Certificate[0])
		Expect(err).NotTo(HaveOccurred())
		certPEM = pem.EncodeToMemory(&pem.Block{Type: "CERTIFICATE", Bytes: cert.Raw})
	}
	var err error
	c, err = boshclient.New(director.URL, authHeaderBuilder, false, certPEM)
	Expect(err).NotTo(HaveOccurred())
	c.BoshPollingInterval = 0
})

func TestBoshclient(t *testing.T) {
	RegisterFailHandler(Fail)
	RunSpecs(t, "Boshclient Suite")
}
