package boshclient_test

import (
	"errors"

	"github.com/pivotal-cf/on-demand-service-broker/boshclient"
	"github.com/pivotal-cf/on-demand-service-broker/mockbosh"

	. "github.com/onsi/ginkgo"
	. "github.com/onsi/gomega"
)

var _ = Describe("deleting bosh deployments", func() {
	var (
		taskID    int
		deleteErr error
	)

	JustBeforeEach(func() {
		taskID, deleteErr = c.DeleteDeployment("some-deployment", logger)
	})

	Context("when the authorization header cannot be generated", func() {
		BeforeEach(func() {
			authHeaderBuilder.BuildReturns("", errors.New("some-error"))
		})

		It("returns an error", func() {
			Expect(deleteErr).To(MatchError(ContainSubstring("some-error")))
		})
	})

	Context("when bosh accepts the delete request", func() {
		BeforeEach(func() {
			director.VerifyAndMock(
				mockbosh.DeleteDeployment("some-deployment").RedirectsToTask(90),
			)
		})

		It("calls the authorization header builder", func() {
			Expect(authHeaderBuilder.BuildCallCount()).To(BeNumerically(">", 0))
		})

		It("returns the bosh task ID", func() {
			Expect(taskID).To(Equal(90))
		})
	})

	Context("when bosh cannot find the deployment", func() {
		BeforeEach(func() {
			director.VerifyAndMock(
				mockbosh.DeleteDeployment("some-deployment").NotFound(),
			)
		})

		It("returns an error", func() {
			Expect(deleteErr).To(BeAssignableToTypeOf(boshclient.DeploymentNotFoundError{}))
		})
	})

	Context("when bosh cannot delete the deployment", func() {
		BeforeEach(func() {
			director.VerifyAndMock(
				mockbosh.DeleteDeployment("some-deployment").Fails("because reasons"),
			)
		})

		It("returns an error", func() {
			Expect(deleteErr).To(MatchError(ContainSubstring("expected status 302, was 500")))
		})
	})
})
