package boshclient

import (
	"fmt"
	"log"
	"net/http"

	"github.com/pivotal-cf/on-demand-services-sdk/bosh"

	"gopkg.in/yaml.v2"
)

func (c *Client) GetManifestRaw(name string, logger *log.Logger) ([]byte, error) {
	logger.Printf("getting manifest from bosh for deployment %s", name)
	respJSON := make(map[string]string)

	err := c.getDataFromBoshCheckingForErrors(
		fmt.Sprintf("%s/deployments/%s", c.boshURL, name),
		http.StatusOK,
		&respJSON,
		logger,
	)

	if err != nil {
		if deploymentDoesNotExistYet(err) {
			return nil, nil
		}
		return nil, err
	}

	return []byte(respJSON["manifest"]), nil
}

func deploymentDoesNotExistYet(err error) bool {
	e, ok := err.(unexpectedStatusError)
	return ok && e.actualStatus == http.StatusNotFound
}

func (c *Client) GetManifest(name string, logger *log.Logger) (*bosh.BoshManifest, error) {
	data, err := c.GetManifestRaw(name, logger)
	if err != nil {
		return nil, err
	}
	if data == nil {
		return nil, nil
	}

	var manifest bosh.BoshManifest
	if err := yaml.Unmarshal(data, &manifest); err != nil {
		return nil, fmt.Errorf("error unmarshalling manifest yaml from %s: %s", data, err)
	}

	return &manifest, nil
}
