package boshclient_test

import (
	"github.com/pivotal-cf/on-demand-service-broker/boshclient"
	"github.com/pivotal-cf/on-demand-service-broker/mockbosh"

	. "github.com/onsi/ginkgo"
	. "github.com/onsi/gomega"
)

var _ = Describe("tasks", func() {
	var (
		taskID = 2112
	)

	Context("getting task state", func() {
		var (
			taskState  boshclient.BoshTask
			getTaskErr error
		)

		JustBeforeEach(func() {
			taskState, getTaskErr = c.GetTask(taskID, logger)
		})

		Context("when bosh fetches the task successfully", func() {
			BeforeEach(func() {
				director.VerifyAndMock(
					mockbosh.Task(taskID).RespondsWithJson(boshclient.BoshTask{State: "a-state", Description: "a-description"}),
				)
			})

			It("returns the task state", func() {
				Expect(taskState).To(Equal(boshclient.BoshTask{State: "a-state", Description: "a-description"}))
			})

			It("does not error", func() {
				Expect(getTaskErr).NotTo(HaveOccurred())
			})
		})

		Context("when bosh fails to fetch the task", func() {
			BeforeEach(func() {
				director.VerifyAndMock(
					mockbosh.Task(taskID).Fails("because reasons"),
				)
			})

			It("wraps the error", func() {
				Expect(getTaskErr).To(MatchError(ContainSubstring("expected status 200, was 500")))
			})
		})
	})

	Context("getting task output", func() {
		var (
			actualTaskOutput    []boshclient.TaskOutput
			actualTaskOutputErr error
			expectedTaskOutputs []boshclient.TaskOutput
		)

		JustBeforeEach(func() {
			actualTaskOutput, actualTaskOutputErr = c.GetTaskOutput(taskID, logger)
		})

		Context("when the client fetches task output of a valid errand task", func() {
			BeforeEach(func() {
				expectedTaskOutputs = []boshclient.TaskOutput{
					{ExitCode: 1, StdOut: "a-description", StdErr: "err"},
					{ExitCode: 2, StdOut: "a-description", StdErr: "err"},
					{ExitCode: 3, StdOut: "a-description", StdErr: "err"},
					{ExitCode: 5, StdOut: "a-description", StdErr: "err"},
				}
				director.VerifyAndMock(
					mockbosh.TaskOutput(taskID).RespondsWithTaskOutput(expectedTaskOutputs),
				)
			})

			It("returns the correct output of the task", func() {
				Expect(actualTaskOutputErr).NotTo(HaveOccurred())
				Expect(actualTaskOutput).To(ConsistOf(expectedTaskOutputs))
			})
		})

		Context("when there is no output", func() {
			BeforeEach(func() {
				director.VerifyAndMock(
					mockbosh.TaskOutput(taskID).RespondsWithTaskOutput([]boshclient.TaskOutput{}),
				)
			})

			It("returns the correct output of the task", func() {
				Expect(actualTaskOutputErr).NotTo(HaveOccurred())
				Expect(actualTaskOutput).To(BeEmpty())
			})
		})

		Context("when bosh fails to fetch the output", func() {
			BeforeEach(func() {
				director.VerifyAndMock(
					mockbosh.TaskOutput(taskID).Fails("because reasons"),
				)
			})

			It("returns an error", func() {
				Expect(actualTaskOutputErr).To(MatchError(ContainSubstring("expected status 200, was 500.")))
			})
		})
	})
})
