package boshclient_test

import (
	. "github.com/onsi/ginkgo"
	. "github.com/onsi/gomega"
	"github.com/pivotal-cf/on-demand-service-broker/mockbosh"
)

var _ = Describe("info", func() {
	Describe("GetDirectorVersion", func() {
		var (
			directorVersionErr error
			directorVersion    string
		)

		JustBeforeEach(func() {
			directorVersion, directorVersionErr = c.GetDirectorVersion(logger)
		})

		AfterEach(func() {
			director.VerifyMocks()
		})

		Context("When fetching the bosh director version succeeds", func() {
			BeforeEach(func() {
				director.VerifyAndMock(
					mockbosh.Info().RespondsWith(
						`{
	            "name": "garden-bosh",
	            "uuid": "b0f9e86f-357f-409c-8f64-a2363d2d9e3b",
	            "version": "1.3262.0.0 (00000000)",
	            "user": null,
	            "cpi": "warden_cpi",
	            "user_authentication": {
	              "type": "basic",
	              "options": {}
	            },
	            "features": {
	              "dns": {
	                "status": false,
	                "extras": {
	                  "domain_name": "bosh"
	                }
	              },
	              "compiled_package_cache": {
	                "status": false,
	                "extras": {
	                  "provider": null
	                }
	              },
	              "snapshots": {
	                "status": false
	              }
	            }
	          }`,
					),
				)
			})

			It("gets bosh director version", func() {
				Expect(directorVersionErr).NotTo(HaveOccurred())
				Expect(directorVersion).To(Equal("1.3262.0"))
			})
		})

		Context("When fetching the bosh director version fails", func() {
			BeforeEach(func() {
				director.VerifyAndMock(
					mockbosh.Info().Fails("nothing today, thank you"),
				)
			})

			It("returns an error", func() {
				Expect(directorVersionErr).To(HaveOccurred())
				Expect(directorVersionErr.Error()).To(ContainSubstring("nothing today, thank you"))
			})
		})
	})
})
