package boshclient

import (
	"fmt"
	"log"
	"net/http"
	"time"

	"github.com/pivotal-cf/on-demand-services-sdk/bosh"
)

func (c *Client) VMs(name string, logger *log.Logger) (bosh.BoshVMs, error) {
	logger.Printf("retrieving VMs for deployment %s from bosh\n", name)
	errs := func(err error) (bosh.BoshVMs, error) {
		return nil, err
	}

	taskID, err := c.getTaskIdFromBoshCheckingForErrors(
		fmt.Sprintf("%s/deployments/%s/vms?format=full", c.boshURL, name),
		http.StatusFound,
		logger,
	)

	if err != nil {
		return errs(err)
	}

	// TODO we only test the polling logic at system test level (when real bosh queues the task, and then takes a long time to do it)
	// We should change that
	for {
		task, getTaskErr := c.GetTask(taskID, logger)
		if getTaskErr != nil {
			return errs(getTaskErr)
		}

		if task.State == BoshTaskError {
			return nil, fmt.Errorf("task %d failed", taskID)
		}

		if task.State == BoshTaskDone {
			logger.Printf("Task %d finished: %s\n", taskID, task.ToLog())
			break
		}

		time.Sleep(time.Second * c.BoshPollingInterval)
	}

	vmsOutputForEachJob, err := c.VMsOutput(taskID, logger)
	if err != nil {
		return errs(err)
	}

	vms := bosh.BoshVMs{}
	for _, vmsOutput := range vmsOutputForEachJob {
		vms[vmsOutput.InstanceGroup] = append(vms[vmsOutput.InstanceGroup], vmsOutput.IPs...)
	}

	return vms, nil
}

type BoshVMsOutput struct {
	IPs           []string
	InstanceGroup string `json:"job_name"`
}

func (c *Client) VMsOutput(taskID int, logger *log.Logger) ([]BoshVMsOutput, error) {
	outputs := []BoshVMsOutput{}
	var output BoshVMsOutput
	outputReadyCallback := func() {
		outputs = append(outputs, output)
		output = BoshVMsOutput{}
		// `output` is reused for JSON decoding, so use a fresh struct;
		// else you will override your previous values with the current one
	}

	err := c.getMultipleDataFromBoshCheckingForErrors(
		fmt.Sprintf("%s/tasks/%d/output?type=result", c.boshURL, taskID),
		http.StatusOK,
		&output,
		outputReadyCallback,
		logger,
	)

	return outputs, err
}
