package broker_test

import (
	"errors"
	"log"

	. "github.com/onsi/ginkgo"
	. "github.com/onsi/gomega"
)

var _ = Describe("counting instances of a service offering by plan", func() {
	var (
		counts   map[string]int
		countErr error

		expectedCounts      = map[string]int{"foo": 4}
		countInstancesCalls int
		logger              *log.Logger
	)

	BeforeEach(func() {
		countInstancesCalls = 0
		cfClient.CountInstancesOfPlansStub = func(id string, _ *log.Logger) (map[string]int, error) {
			countInstancesCalls++

			if countInstancesCalls == 1 {
				return map[string]int{}, nil
			}

			Expect(id).To(Equal(serviceOfferingID))
			return expectedCounts, errors.New("oh dear")
		}
	})

	JustBeforeEach(func() {
		logger = loggerFactory.NewLogger()
		counts, countErr = b.CountInstancesOfPlans(logger)
	})

	It("returns the instance count", func() {
		Expect(counts).To(Equal(expectedCounts))
	})

	It("returns the error from CF client", func() {
		Expect(countErr).To(MatchError("oh dear"))
	})
})
