package broker

import (
	"errors"
	"fmt"
)

const genericErrorMessage = "An internal error has occurred"

type NotFoundError struct {
	error
}

func NewNotFoundError() NotFoundError {
	return NotFoundError{error: errors.New("resource was not found")}
}

func IsNotFound(err error) bool {
	switch err.(type) {
	case NotFoundError:
		return true
	default:
		return false
	}
}

type DeploymentNotFoundError struct {
	error
}

func NewDeploymentNotFoundError(e error) error {
	return DeploymentNotFoundError{e}
}

type OperationInProgressError struct {
	error
}

func NewOperationInProgressError(e error) error {
	return OperationInProgressError{e}
}

type ServiceAdapterCommandNotImplementedError struct {
	error
}

func NewServiceAdapterCommandNotImplementedError(e error) ServiceAdapterCommandNotImplementedError {
	return ServiceAdapterCommandNotImplementedError{e}
}

type DisplayableError struct {
	errorForCFUser   error
	errorForOperator error
}

func (e DisplayableError) ErrorForCFUser() error {
	return e.errorForCFUser
}

func (e DisplayableError) Error() string {
	return fmt.Sprintf("error: %s. error for user: %s.", e.errorForOperator, e.errorForCFUser)
}

func NewDisplayableError(errorForCFUser, errForOperator error) DisplayableError {
	return DisplayableError{
		errorForCFUser,
		errForOperator,
	}
}

func NewBoshRequestError(action string, requestError error) DisplayableError {
	return DisplayableError{
		fmt.Errorf("Currently unable to %s service instance, please try again later", action),
		requestError,
	}
}

func NewGenericError(err error) DisplayableError {
	return DisplayableError{
		errorForCFUser:   errors.New(genericErrorMessage),
		errorForOperator: err,
	}
}
