package broker_test

import (
	"errors"
	"log"

	. "github.com/onsi/ginkgo"
	. "github.com/onsi/gomega"
)

var _ = Describe("Instances", func() {
	Describe("listing all instances", func() {
		var logger *log.Logger

		BeforeEach(func() {
			cfClient.GetInstancesOfServiceOfferingReturns([]string{"red", "green", "blue"}, nil)
			logger = loggerFactory.NewLogger()
		})

		It("returns a list of instance IDs", func() {
			Expect(b.Instances(logger)).To(ConsistOf("red", "green", "blue"))
		})

		Context("when the list of instances cannot be retrieved", func() {
			BeforeEach(func() {
				cfClient.GetInstancesOfServiceOfferingReturns(nil, errors.New("fnuh"))
			})

			It("returns an error", func() {
				_, err := b.Instances(logger)
				Expect(err).To(MatchError(ContainSubstring("fnuh")))
			})
		})
	})
})
