package broker

import (
	"log"
	"strings"
)

func (b *Broker) OrphanDeployments(logger *log.Logger) ([]string, error) {
	rawInstanceIDs, err := b.Instances(logger)
	if err != nil {
		logger.Printf("error listing instances: %s", err)
		return nil, err
	}

	instanceIDs := map[string]bool{}
	for _, instance := range rawInstanceIDs {
		instanceIDs[instance] = true
	}

	deployments, err := b.boshClient.GetDeployments(logger)
	if err != nil {
		logger.Printf("error getting deployments: %s", err)
		return nil, err
	}

	var orphanDeploymentNames []string
	for _, deployment := range deployments {
		if !strings.HasPrefix(deployment.Name, InstancePrefix) {
			continue
		}

		if !instanceIDs[instanceID(deployment.Name)] {
			orphanDeploymentNames = append(orphanDeploymentNames, deployment.Name)
		}
	}

	return orphanDeploymentNames, nil
}
