package broker

import "github.com/pivotal-cf/on-demand-services-sdk/serviceadapter"

type ServiceOffering struct {
	ID               string
	Name             string `yaml:"service_name"`
	Description      string `yaml:"service_description"`
	Bindable         bool
	PlanUpdatable    bool     `yaml:"plan_updatable"`
	Requires         []string `yaml:"requires,omitempty"`
	Metadata         ServiceMetadata
	DashboardClient  *DashboardClient `yaml:"dashboard_client,omitempty"`
	Tags             []string
	GlobalProperties serviceadapter.Properties `yaml:"global_properties"`
	Plans            Plans
}

type Plans []Plan

func (plans Plans) Contains(planID string) bool {
	for _, item := range plans {
		if item.ID == planID {
			return true
		}
	}
	return false
}

type Plan struct {
	ID             string `yaml:"plan_id"`
	Name           string
	Free           *bool
	Description    string
	Metadata       PlanMetadata
	Quotas         *Quotas `yaml:"quotas,omitempty"`
	Properties     serviceadapter.Properties
	InstanceGroups []serviceadapter.InstanceGroup `yaml:"instance_groups,omitempty"`
	Update         *serviceadapter.Update         `yaml:"update,omitempty"`
}

type PlanMetadata struct {
	DisplayName string     `yaml:"display_name"`
	Bullets     []string   `yaml:"bullets,omitempty"`
	Costs       []PlanCost `yaml:"costs"`
}

type PlanCost struct {
	Amount map[string]float64 `yaml:"amount"`
	Unit   string             `yaml:"unit"`
}

type ServiceMetadata struct {
	DisplayName         string `yaml:"display_name"`
	ImageURL            string `yaml:"image_url"`
	LongDescription     string `yaml:"long_description"`
	ProviderDisplayName string `yaml:"provider_display_name"`
	DocumentationURL    string `yaml:"documentation_url"`
	SupportURL          string `yaml:"support_url"`
}

type DashboardClient struct {
	ID          string
	Secret      string
	RedirectUri string `yaml:"redirect_uri"`
}

type Quotas struct {
	ServiceInstanceLimit int `yaml:"service_instance_limit"`
}

func (c ServiceOffering) FindPlanById(planId string) *Plan {
	for _, plan := range c.Plans {
		if plan.ID == planId {
			return &plan
		}
	}
	return nil
}
