package broker

import (
	"context"
	"errors"
	"fmt"

	"github.com/pivotal-cf/brokerapi"
	"github.com/pivotal-cf/on-demand-service-broker/boshclient"
	"github.com/pivotal-cf/on-demand-services-sdk/serviceadapter"
)

func (b *Broker) Unbind(_ context.Context, instanceID, bindingID string, details brokerapi.UnbindDetails) error {
	logger := b.loggerFactory.NewLogger()

	errs := func(err error) error {
		return convertToDisplayableError(err, logger)
	}

	vms, manifest, err := b.getDeploymentInfo(instanceID, logger)
	switch err.(type) {
	case boshclient.DeploymentNotFoundError:
		return errs(NewDisplayableError(brokerapi.ErrInstanceDoesNotExist, fmt.Errorf("error unbinding: instance %s, not found", instanceID)))
	case error:
		return errs(fmt.Errorf("gathering unbinding info %s", err))
	}

	requestParams := map[string]interface{}{
		"plan_id":    details.PlanID,
		"service_id": details.ServiceID,
	}

	logger.Printf("service adapter will delete binding with ID %s for instance %s\n", bindingID, instanceID)
	bindingErr := b.serviceAdapter.DeleteBinding(bindingID, vms, manifest, requestParams, logger)
	switch bindingErr.(type) {
	case serviceadapter.BindingNotFoundError:
		return errs(NewDisplayableError(brokerapi.ErrBindingDoesNotExist, errors.New("deleting binding")))
	case error:
		return errs(bindingErr)
	}

	return nil
}
