package broker

import (
	"fmt"
	"log"
)

func (b *Broker) Upgrade(instanceID string, logger *log.Logger) (int, error) {
	b.deploymentLock.Lock()
	defer b.deploymentLock.Unlock()

	instance, err := b.cfClient.GetInstanceState(instanceID, logger)
	if err != nil {
		if IsNotFound(err) {
			return 0, NewDeploymentNotFoundError(err)
		}
		return 0, err
	}

	if instance.OperationInProgress {
		return 0, NewOperationInProgressError(fmt.Errorf("cloud controller: operation in progress for instance %s", instanceID))
	}

	logger.Printf("upgrading instance %s", instanceID)

	taskID, err := b.redeploy(instanceID, instance.PlanID, OperationTypeUpgrade, nil, &instance.PlanID, logger)
	if err != nil {
		logger.Printf("error upgrading instance %s: %s", instanceID, err)
		return 0, err
	}

	return taskID, nil
}
