package cloud_foundry_client

import "time"

type serviceResponse struct {
	commonHeader
	Services services `json:"resources"`
}

type services []service

func (services services) findByUniqueID(id string) *service {
	for _, service := range services {
		if service.ServiceEntity.UniqueID == id {
			return &service
		}
	}
	return nil
}

type service struct {
	ServiceEntity serviceEntity `json:"entity"`
}
type serviceEntity struct {
	UniqueID        string `json:"unique_id"`
	ServicePlansUrl string `json:"service_plans_url"`
}

type commonHeader struct {
	TotalResults int    `json:"total_results"`
	TotalPages   int    `json:"total_pages"`
	NextPath     string `json:"next_url"`
}

type infoResponse struct {
	APIVersion string `json:"api_version"`
}

type oauthTokenResponse struct {
	AccessToken  string        `json:"access_token"`
	RefreshToken string        `json:"refresh_token"`
	ExpiresIn    time.Duration `json:"expires_in"`
}

type ServicePlanResponse struct {
	commonHeader
	ServicePlans []ServicePlan `json:"resources"`
}
type ServicePlan struct {
	Metadata          Metadata          `json:"metadata"`
	ServicePlanEntity ServicePlanEntity `json:"entity"`
}
type ServicePlanEntity struct {
	UniqueID            string `json:"unique_id"`
	ServiceInstancesUrl string `json:"service_instances_url"`
}

type serviceInstance struct {
	Metadata Metadata              `json:"metadata"`
	Entity   serviceInstanceEntity `json:"entity"`
}

type Metadata struct {
	GUID string `json:"guid"`
}

type lastOperation struct {
	State string `json:"state"`
}

type serviceInstanceEntity struct {
	ServicePlanURL string        `json:"service_plan_url"`
	LastOperation  lastOperation `json:"last_operation"`
}

type serviceInstancesResponse struct {
	commonHeader
	ServiceInstances []serviceInstance `json:"resources"`
}
