package main

import (
	"flag"
	"fmt"
	"io/ioutil"
	"net/http"
	"os"
	"time"

	"github.com/craigfurman/herottp"
)

const (
	NotReadyYetExitCode = 10
	emptyListOfMetrics  = "[]"
)

func main() {
	brokerUsername := flag.String("brokerUsername", "", "username for the broker")
	brokerPassword := flag.String("brokerPassword", "", "password for the broker")
	brokerUrl := flag.String("brokerUrl", "", "url of the broker")
	flag.Parse()

	brokerMetricsUrl := *brokerUrl + "/mgmt/metrics"
	client := herottp.New(herottp.Config{Timeout: 30 * time.Second})

	request, err := http.NewRequest("GET", brokerMetricsUrl, nil)
	if err != nil {
		fatalError(err)
	}
	request.SetBasicAuth(*brokerUsername, *brokerPassword)
	response, err := client.Do(request)
	if err != nil {
		fatalError(err)
	}

	switch response.StatusCode {
	case http.StatusInternalServerError:
		// Prevent an error retrieving metrics from causing service-metrics to fail
		fmt.Print(emptyListOfMetrics)
		os.Exit(0)
	case http.StatusServiceUnavailable:
		os.Exit(NotReadyYetExitCode)
	}

	defer response.Body.Close()
	body, err := ioutil.ReadAll(response.Body)
	if err != nil {
		fatalError(err)
	}

	fmt.Print(string(body))
}

func fatalError(err error) {
	fmt.Printf("error collecting metrics: %s", err)
	os.Exit(1)
}
