package main

import (
	"flag"
	"log"
	"os"

	"github.com/pivotal-cf/on-demand-service-broker/cmd/upgrade-sub-deployments/messages"
	"github.com/pivotal-cf/on-demand-service-broker/upgrader"
)

var logger *log.Logger

func main() {
	brokerUsername := flag.String("brokerUsername", "", "username for the broker")
	brokerPassword := flag.String("brokerPassword", "", "password for the broker")
	brokerUrl := flag.String("brokerUrl", "", "url of the broker")
	pollingInterval := flag.Int64("pollingInterval", 5000, "interval for checking the upgrade in ms")

	logger = log.New(os.Stdout, "[upgrade-all-instances] ", log.LstdFlags)

	flag.Parse()

	if *brokerUsername == "" || *brokerPassword == "" || *brokerUrl == "" {
		logger.Fatalf("the brokerUsername, brokerPassword and brokerUrl are required to function")
	}
	instances, skippedInstances, err := upgrader.New(*brokerUsername, *brokerPassword, *brokerUrl, *pollingInterval).Upgrade()
	if err != nil {
		logger.Fatalf(err.Error())
	}
	if len(skippedInstances) > 0 {
		logger.Printf(messages.UpgradeSuccededWithWarnings)
		for _, skippedInstance := range skippedInstances {
			logger.Printf(messages.UpgradeSkippedInstance, skippedInstance)
		}
		logger.Printf(messages.UpgradeSuccededWithNumberOfInstances, len(instances))
		os.Exit(0)
	}

	logger.Printf(messages.UpgradeSuccessMessage)
}
