package external

import (
	"bytes"
	"os/exec"
	"syscall"
)

//go:generate counterfeiter -o fake_command_runner/fake_command_runner.go . CommandRunner
type CommandRunner interface {
	Run(arg ...string) ([]byte, []byte, *int, error)
}

func NewCommandRunner() CommandRunner {
	return commandRunner{}
}

type commandRunner struct{}

func (c commandRunner) Run(arg ...string) ([]byte, []byte, *int, error) {
	var stderr bytes.Buffer
	cmd := exec.Command(arg[0], arg[1:]...)
	cmd.Stderr = &stderr

	stdout, err := cmd.Output()

	var exitCode *int

	if err != nil {
		if exitErr, ok := err.(*exec.ExitError); ok {
			exitCode = intPtr(exitErr.Sys().(syscall.WaitStatus).ExitStatus())
			err = nil
		}
	} else {
		exitCode = intPtr(0)
	}

	return stdout, stderr.Bytes(), exitCode, err
}

func intPtr(val int) *int {
	return &val
}
