package loggerfactory_test

import (
	"bytes"
	"log"

	"github.com/pivotal-cf/on-demand-service-broker/loggerfactory"

	. "github.com/onsi/ginkgo"
	. "github.com/onsi/gomega"
)

var _ = Describe("LoggerFactory", func() {
	It("can return a logger that logs messages with request ID", func() {
		logs := &bytes.Buffer{}
		factory := loggerfactory.New(logs, "[prefix] ", log.LstdFlags)
		logger := factory.NewLogger()
		logger.Println("ohai")
		Expect(logs.String()).To(MatchRegexp(`\[prefix\] \[[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\] \d{4}/\d{2}/\d{2} \d{2}:\d{2}:\d{2} ohai`))
	})

	It("can return a logger that logs messages without request ID", func() {
		logs := &bytes.Buffer{}
		factory := loggerfactory.New(logs, "[prefix] ", log.LstdFlags)
		logger := factory.NewLoggerWithoutRequestID()
		logger.Println("ohai")
		Expect(logs.String()).To(MatchRegexp(`\[prefix\] \d{4}/\d{2}/\d{2} \d{2}:\d{2}:\d{2} ohai`))
	})
})
